// Imports

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;



/**
 * This class demonstrates the Bidi text feature in Swing 1.1 under JDK 1.2 .
 */
public class BidiDemo extends JApplet implements ActionListener
{
    ImageIcon       icon = new ImageIcon("duke.gif");

    JPanel          panel = new JPanel(new GridLayout(4, 2, 10, 5));

    JButton         but1 = new JButton("LEADING", icon);
    JButton         but2 = new JButton("TRAILING", icon);

    JCheckBox       box1 = new JCheckBox("LEADING");
    JCheckBox       box2 = new JCheckBox("TRAILING");

    JRadioButton    radio1 = new JRadioButton("LEADING");
    JRadioButton    radio2 = new JRadioButton("TRAILING");

    JLabel          label1 = new JLabel("LEADING", icon, JLabel.CENTER);
    JLabel          label2 = new JLabel("TRAILING", icon, JLabel.CENTER);

    JButton         switchOrientation = new JButton("Orientation: " +
                                                    "Left to Right");

    boolean         left2right = true;


    /**
     * Constructor for class BidiDemo.
     */
    public BidiDemo() {
        // Set the horizontal alignment and the horizontal text position for
        // all the components.

        but1.setHorizontalAlignment(JButton.LEADING);
        but1.setHorizontalTextPosition(JButton.LEADING);

        but2.setHorizontalAlignment(JButton.TRAILING);
        but2.setHorizontalTextPosition(JButton.TRAILING);

        box1.setHorizontalAlignment(JCheckBox.LEADING);
        box1.setHorizontalTextPosition(JCheckBox.LEADING);

        box2.setHorizontalAlignment(JCheckBox.TRAILING);
        box2.setHorizontalTextPosition(JCheckBox.TRAILING);

        label1.setHorizontalAlignment(JLabel.LEADING);
        label1.setHorizontalTextPosition(JLabel.LEADING);

        label2.setHorizontalAlignment(JLabel.TRAILING);
        label2.setHorizontalTextPosition(JLabel.TRAILING);

        radio1.setHorizontalAlignment(JRadioButton.LEADING);
        radio1.setHorizontalTextPosition(JRadioButton.LEADING);

        radio2.setHorizontalAlignment(JRadioButton.TRAILING);
        radio2.setHorizontalTextPosition(JRadioButton.TRAILING);

        // Place the components in the panel.
        panel.add(but1);
        panel.add(but2);
        panel.add(box1);
        panel.add(box2);
        panel.add(label1);
        panel.add(label2);
        panel.add(radio1);
        panel.add(radio2);

        switchOrientation.addActionListener(this);

        this.getContentPane().setLayout(new BorderLayout());
        this.getContentPane().add(panel, BorderLayout.CENTER);
        this.getContentPane().add(switchOrientation, BorderLayout.SOUTH);
    }


    /**
     * Event handler for the button clicks.
     */
    public void actionPerformed(ActionEvent ev) {
        if (ev.getSource() == switchOrientation) {
            if (left2right) {
                // Set the orientation of each component
                // to RIGHT_TO_LEFT.
                but1.setComponentOrientation(
                                    ComponentOrientation.RIGHT_TO_LEFT);
                but2.setComponentOrientation(
                                    ComponentOrientation.RIGHT_TO_LEFT);
                box1.setComponentOrientation(
                                    ComponentOrientation.RIGHT_TO_LEFT);
                box2.setComponentOrientation(
                                    ComponentOrientation.RIGHT_TO_LEFT);
                radio1.setComponentOrientation(
                                    ComponentOrientation.RIGHT_TO_LEFT);
                radio2.setComponentOrientation(
                                    ComponentOrientation.RIGHT_TO_LEFT);
                label1.setComponentOrientation(
                                    ComponentOrientation.RIGHT_TO_LEFT);
                label2.setComponentOrientation(
                                    ComponentOrientation.RIGHT_TO_LEFT);

                switchOrientation.setText("Orientation: Right to Left");

                left2right = false;
            }
            else {
                // Set the orientation of each component
                // to LEFT_TO_RIGHT.
                but1.setComponentOrientation(
                                    ComponentOrientation.LEFT_TO_RIGHT);
                but2.setComponentOrientation(
                                    ComponentOrientation.LEFT_TO_RIGHT);
                box1.setComponentOrientation(
                                    ComponentOrientation.LEFT_TO_RIGHT);
                box2.setComponentOrientation(
                                    ComponentOrientation.LEFT_TO_RIGHT);
                radio1.setComponentOrientation(
                                    ComponentOrientation.LEFT_TO_RIGHT);
                radio2.setComponentOrientation(
                                    ComponentOrientation.LEFT_TO_RIGHT);
                label1.setComponentOrientation(
                                    ComponentOrientation.LEFT_TO_RIGHT);
                label2.setComponentOrientation(
                                    ComponentOrientation.LEFT_TO_RIGHT);

                switchOrientation.setText("Orientation: Left to Right");

                left2right = true;
            }
        }
        panel.revalidate();
        repaint();
    }


    /**
     * Main method
     */
    static public void main(String args[]) {
        JFrame frame = new JFrame("Bidi Text Demonstration");
        frame.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });

        BidiDemo demo = new BidiDemo();

        frame.getContentPane().add(demo);

        frame.setSize(400, 400);
        frame.setVisible(true);
    }
}
